@@ -39,19 +39,47 @@ pub fn dyn_partial_eq(_: TokenStream, input: TokenStream) -> TokenStream {
 
   input.supertraits.push(bound);
 
-  (quote! {
-    #input
-
-    impl core::cmp::PartialEq for Box<dyn #name> {
+  let no_std_derive = quote! {
+    impl core::cmp::PartialEq for dyn #name {
       fn eq(&self, other: &Self) -> bool {
         self.box_eq(other.as_any())
       }
     }
+  };
 
-    impl core::cmp::PartialEq<&Self> for Box<dyn #name> {
-      fn eq(&self, other: &&Self) -> bool {
-        self.box_eq(other.as_any())
-      }
+  cfg_if::cfg_if! {
+    if #[cfg(feature="std")] {
+      let expanded = quote! {
+        #input
+
+        #no_std_derive
+
+        impl core::cmp::PartialEq<&Self> for std::boxed::Box<dyn #name> {
+          fn eq(&self, other: &&Self) -> bool {
+            self.box_eq(other.as_any())
+          }
+        }
+      };
+    } else if #[cfg(feature="alloc")] {
+      let expanded = quote! {
+        #input
+
+        #no_std_derive
+
+        impl core::cmp::PartialEq<&Self> for alloc::boxed::Box<dyn #name> {
+          fn eq(&self, other: &&Self) -> bool {
+            self.box_eq(other.as_any())
+          }
+        }
+      };
+    } else {
+      let expanded = quote! {
+        #input
+
+        #no_std_derive
+      };
     }
-  }).into()
+  };
+
+  expanded.into()
 }
